function [y,T,lam,res,iter,A,p,jac]=honloopext(p,y1,T1,lam1,ds,varargin)
% honloopext: Newton loop for Hopf in arclength
if p.fsol.fsol==1; % use fsolve 
    [y,T,lam,res,iter,A,p,jac]=fsolext(p,y1,T1,lam1,ds); return; end
try; freeT=p.freeT; catch; freeT=1; end % check if T is free (default) 
par=getaux(p); tol=p.nc.tol; nqh=p.hopf.nqh;  
if nqh>0 || ~freeT; a=p.u(p.nu+p.hopf.ilam); else; a=0; end; 
iter=0; y=y1; T=T1; lam=lam1; 
p=setlam(p,lam); % set lam to predictor
nu=p.nu; tl=p.hopf.tl; na=nu+p.nc.nq; alpha=1; almin=alpha/8; % minimal damping 
[f,jac,f_T,f_lam,f_a]=tomassempbc(p,y,T,lam); 
[pc,pc_y]=hopc(p,y,T,lam); arcl=hoarcl(p,y,T,lam,ds,a); 
qf=[]; if nqh>0; qf=p.hopf.qfh(p,y); end 
F=[f; pc; arcl; qf]; res0=norm(F,p.sw.norm); res=res0; 
if p.sw.verb>1;  fprintf('initial (||f||, pc, arcl)=(%g,%g,%g)\n',norm(f,p.sw.norm),pc,arcl); end
qhder=[]; 
if nqh>0; qhder=getqhder(p,y); A=gethoA(p,jac,f_T,f_lam,pc_y,p.hopf.tau,f_a,qhder); 
else; A=gethoA(p,jac,f_T,f_lam,pc_y,p.hopf.tau,f_a); 
end
%figure(10); spy(A), pause 
if(res<tol); return; end; % initial res. small, do nothing! 
% now start the actual loop
stepok=1; % stepok=1 indicates that step of size alpha decreased residual  
while(abs(res0)>tol && iter<p.nc.imax && stepok) 
  [upd,p]=p.fuha.blss(A,F,p); %upd', pause
  stepok=0; yv=reshape(y(1:nu,:),nu*tl,1); % make y-vector
  while(stepok==0 && alpha>=almin)   
  y1=yv-alpha*upd(1:nu*tl); 
  if freeT; tupd=upd(nu*tl+1); T1=T-alpha*tupd; 
     lam1=lam-alpha*upd(nu*tl+2); 
     if nqh>0; a1=a-alpha*upd(na*tl+3:end); p.u(p.nu+p.hopf.ilam)=a1; end 
  else; T1=T;  lam1=lam-alpha*upd(na*tl+1); 
     a=p.u(p.nu+p.hopf.ilam); 
     a1=a-alpha*upd(na*tl+2:end); % lam,lam1,a,a1, pause
     p.u(p.nu+p.hopf.ilam)=a1;%  102, lam, lam1
  end 
  ytom=reshape(y1(1:nu*tl),nu,tl); % convert to tom-input 
  f=tomassempbc(p,ytom,T1,lam1);  % setlam(p,lam1) done in tomassempbc! 
  [pc,pc_y]=hopc(p,ytom,T1,lam1); 
  if freeT; 
     if nqh==0; arcl=hoarcl(p,ytom,T1,lam1,ds); 
     else; arcl=hoarcl(p,ytom,T1,lam1,ds,a1); qf=p.hopf.qfh(p,y); 
     end
  else 
    p.u(p.nu+p.hopf.ilam)=a; %(1:end-1); 
    arcl=hoarcl(p,ytom,T1,lam1,ds,a1); 
    p.u(p.nu+p.hopf.ilam)=a1; 
  end 
  F=[f; pc; arcl]; if nqh>0; F=[F; qf]; end 
  if p.sw.verb>1; 
      fprintf('al=%g, (||f||, pc, arcl)=(%g,%g,%g)\n',alpha,norm(f,p.sw.norm),pc,arcl);end
  res=norm(F,p.sw.norm); % check new tom-resi 
  if(res<res0); % good step       
    if(res<res0/2 && alpha<1) alpha=alpha*2; end % very good step  
    stepok=1; y=ytom; T=T1; lam=lam1; res0=res;
    if nqh==0; 
     [f,jac,f_T,f_lam,f_a]=tomassempbc(p,y,T,lam); [pc,pc_y]=hopc(p,y,T,lam); 
     A=gethoA(p,jac,f_T,f_lam,pc_y,p.hopf.tau,f_a); 
    else a=a1; [f,jac,f_T,f_lam, f_a]=tomassempbc(p,y,T,lam); 
     [pc,pc_y]=hopc(p,y,T,lam); qhder=getqhder(p,y); 
     A=gethoA(p,jac,f_T,f_lam,pc_y,p.hopf.tau,f_a,qhder); 
    end
  else alpha=alpha/2; % bad step, try smaller alpha
  end % res<res0
  end % while stepok==0
  iter=iter+1;
end % while res<p.nc.tol && stepok 
% ----------------------------------------------------------postprocessing
if(p.sw.verb>1); if(alpha<1) fprintf('\nhonloopext: damp alpha=%g, res=%g, ds=%g\n',...
            alpha,res,ds); end; end; % inform user if damping was used 
res=res0; y=ytom;

